aind\_data\_schema.schema\_upgrade package
==========================================

Submodules
----------

aind\_data\_schema.schema\_upgrade.data\_description\_upgrade module
--------------------------------------------------------------------

.. automodule:: aind_data_schema.schema_upgrade.data_description_upgrade
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_data_schema.schema_upgrade
   :members:
   :undoc-members:
   :show-inheritance:
